#2D plot stuff
library(FactoMineR)
library(plotrix)
library("factoextra")
library(ggplot2)

library(grid)

soundGroups=read.csv("allMaster.csv", header = TRUE, row.names = 1, sep = ",")
res.ca = CA(soundGroups, ncp=9)

#colCoord<-res.ca$col$coord
#write.csv(colCoord, file="wordCoord.csv", row.names=TRUE) #<- add word types to this

res.hcpc<-HCPC(res.ca, cluster.CA="rows")


fviz_gg<-fviz_cluster(res.hcpc, ggtheme = theme_bw(), main="", labelsize = 12, ellipse.type = "norm")


title.text<-element_text(size=20, face="bold")
tick.text<-element_text(size=15)

p1<-ggplot(fviz_gg$data, aes(x,y, colour=cluster, shape=cluster))+
geom_text_repel(aes(label=name),show.legend = FALSE)+
geom_point()+
theme_bw()+
labs(x="Dimension 1", y="Dimension 2")+
coord_cartesian(xlim = c(-2.5, 2.5),ylim = c(-2.5, 2.5)) +
scale_colour_manual(values = c("1"="deepskyblue","2"="firebrick","3"="chartreuse4"))+
theme(
	axis.title=title.text,
	axis.text=tick.text,
	panel.grid	= element_blank(),
	panel.border=element_blank(),
	axis.line = element_line(colour = "black"),
	legend.position = c(0.85, 0.85), 
	legend.text=tick.text,
	legend.title=tick.text
)	


df=read.csv("wordCoord.csv", header = TRUE, sep = ",")
head(df)


p2<-ggplot(df, aes(Dim.1, Dim.2, colour=Type, shape=Type))+
geom_text_repel(aes(label=Word),show.legend = FALSE)+
geom_point()+
theme_bw()+
labs(x="Dimension 1", y="Dimension 2")+
coord_cartesian(xlim = c(-2.5, 2.5),ylim = c(-2.5, 2.5)) +
scale_colour_manual(values = c("Source"="deepskyblue","Signal"="firebrick","Affect-judgement"="chartreuse4"))+
theme(
	axis.title=title.text,
	axis.text=tick.text,
	panel.grid	= element_blank(),
	panel.border=element_blank(),
	axis.line = element_line(colour = "black"),
	legend.position = c(0.2, 0.2), 
	legend.text=tick.text,
	legend.title=tick.text
)		

setEPS()
postscript("nature_2D.eps", family="Times", width=14, height=7)


grid.newpage()
pushViewport(viewport(layout = grid.layout(nrow=1, ncol=2)))

print(p1, vp = viewport(layout.pos.row = 1, layout.pos.col = 1))
print(p2, vp = viewport(layout.pos.row = 1, layout.pos.col = 2))


dev.off()
